pwrcheck - Python PWRCheck Reader
*********************************


Build Status
============

Master:

.. image:: https://travis-ci.org/ampledata/pwrcheck.svg?branch=master
    :target: https://travis-ci.org/ampledata/pwrcheck

Develop:

.. image:: https://travis-ci.org/ampledata/pwrcheck.svg?branch=develop
    :target: https://travis-ci.org/ampledata/pwrcheck


Source
======
Github: https://github.com/ampledata/pwrcheck

Author
======
Greg Albrecht W2GMD oss@undef.net

http://ampledata.org/

Copyright
=========
Copyright 2018 Greg Albrecht

License
=======
Apache License, Version 2.0. See LICENSE for details.
